<div id="popupEditDomain" class="modal" tabindex="-1" role="dialog">
    <div class="modal-dialog" role="document">
        <div class="modal-content"></div>
    </div>
</div>

<script type="text/javascript">

function show_edit_popup(domain_id) {
  href = "{% url 'ping_me:ajax-edit-popup' domain_pk=12345 %}".replace('12345', domain_id);

  $.ajax({
    type: 'GET',
    url: href,
    success: function(data, textStatus, jqXHR) {
      $('#popupEditDomain').find('.modal-content').html(data);
      $('#popupEditDomain').modal('show');
    }
  });
}

</script>