
{% if summary %}

    {% if summary.percentage <= 50 %}
    <span class="badge badge-danger" title="{{ summary.to_str }}">
    {% elif summary.percentage <= 90 %}
    <span class="badge badge-warning" title="{{ summary.to_str }}">
    {% elif summary.percentage <= 99 %}
    <span class="badge badge-info" title="{{ summary.to_str }}">
    {% else %}
    <span class="badge badge-success" title="{{ summary.to_str }}">
    {% endif %}
        {{ summary.percentage|floatformat }} %
    </span>
{% else %}
    <span class="badge badge-secondary" title="No request sended">
        N/A
    </span>

{% endif %}