<form method="post">
    {% csrf_token %}

    <div class="modal-header">
        <h5 class="modal-title">
            Delete a domain
        </h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
            <span aria-hidden="true">&times;</span>
        </button>
    </div>
    <div class="modal-body">
        <p>Are you sure to delete domain <b>{{ domain.url }}</b>?</p>
    </div>
    <div class="modal-footer">
        <input type="hidden" id="hdnDomainId" name="hdnDomainId" value="{{ domain.id }}">
        <button class="btn btn-secondary" data-dismiss="modal">Cancel</button>
        <button name="btnDeleteDomain" class="btn btn-primary">Accept</button>
    </div>

</form>